@@ -2,7 +2,7 @@
 // the Swarm room
 // variables and methods for exchange class
 
-#import <swarmobject.h>
+#import <objectbase/SwarmObject.h>
 #import <collections.h>
 
 typedef struct trader{
@@ -10,7 +10,8 @@ typedef struct trader{
   id who;
 } trader;
 
-@interface Exchange : SwarmObject {
+@interface Exchange: SwarmObject
+{
   id traderSet;
   int excess;
   int balance;
